@@ -16,12 +16,14 @@ pub use role::RoleExt;
 pub use role_binding::RoleBindingExt;
 pub use secret::SecretExt;
 pub use service_account::ServiceAccountExt;
+pub use policy_rule::PolicyRuleExt;
 
 mod cluster_role;
 mod cluster_role_binding;
 mod configmap;
 mod deployment;
 mod namespace;
+mod policy_rule;
 mod role;
 mod role_binding;
 mod secret;
